﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;

using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                             += Form_Load;
            this.treeList.CustomDrawNodeCell += treeList_CustomDrawNodeCell;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.ReadOnly               = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.BestFitColumns();
        }

        #endregion
        #region 트리 리스트 노드 셀 커스텀 그리기 - treeList_CustomDrawNodeCell(sender, e)

        /// <summary>
        /// 트리 리스트 노드 셀 커스텀 그리기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_CustomDrawNodeCell(object sender, CustomDrawNodeCellEventArgs e)
        {
            Brush backgroundBrush;
            Brush foregroundBrush;

            if(e.Node != (sender as TreeList).FocusedNode)
            {
                backgroundBrush = e.Cache.GetGradientBrush
                (
                    e.Bounds,
                    Color.PapayaWhip,
                    Color.PeachPuff,
                    LinearGradientMode.ForwardDiagonal
                );

                foregroundBrush = Brushes.Black;
            }
            else
            {
                backgroundBrush = Brushes.DarkBlue;

                foregroundBrush = e.Cache.GetSolidBrush(Color.PeachPuff);
            }

            e.Cache.FillRectangle(backgroundBrush, e.Bounds);

            e.Cache.DrawString(e.CellText, e.Appearance.Font, foregroundBrush, e.Bounds,

            e.Appearance.GetStringFormat());

            e.Handled = true;
        }

        #endregion
    }
}